import json
from pathlib import Path
import unittest

from pyson.ObjectMapper import ObjectMapper

from geniusweb.profile.Profile import Profile


class LinearAdditiveSerializationTest(unittest.TestCase):
    pyson=ObjectMapper()
    
    jobsstr = '{"LinearAdditiveUtilitySpace":{"issueUtilities":{'  \
        + '"lease car":{"DiscreteValueSetUtilities":{"valueUtilities":{"no":0,"yes":1}}},' \
        + '"permanent contract":{"DiscreteValueSetUtilities":{"valueUtilities":{"no":0,"yes":1}}},'  \
        + '"career development opportunities":{"DiscreteValueSetUtilities":{"valueUtilities":{"high":1,"low":0,"medium":0.5}}},' \
        + '"fte":{"DiscreteValueSetUtilities":{"valueUtilities":{"1.0":0.75,"0.6":0.25,"0.8":0.5}}},' \
        + '"salary":{"DiscreteValueSetUtilities":{"valueUtilities":{"4000":1.0,"2500":0.25,"3500":0.75,"2000":0,"3000":0.3}}},' \
        + '"work from home":{"DiscreteValueSetUtilities":{"valueUtilities":{"1":0.5,"2":0.666666666666,"0":0.333333333}}}},' \
        + '"issueWeights":{"lease car":0.06,"permanent contract":0.16,' \
        + '"career development opportunities":0.04,"fte":0.32,"salary":0.24,"work from home":0.18},' \
        + '"domain":{"name":"jobs","issuesValues":{"lease car":{"values":["yes","no"]},"permanent contract":{"values":["yes","no"]},"career development opportunities":{"values":["low","medium","high"]},"fte":{"values":["0.6","0.8","1.0"]},"salary":{"values":["2000","2500","3000","3500","4000"]},"work from home":{"values":["0","1","2"]}}},"name":"jobs1"}}'

    jobsjson = json.loads(jobsstr)

    partystr='{"LinearAdditiveUtilitySpace":{"domain":{"name":"party","issuesValues":{"Invitations":{"values":["Plain","Photo","Custom, Handmade","Custom, Printed"]},"Music":{"values":["MP3","DJ","Band"]},"Drinks":{"values":["Non-Alcoholic","Beer Only","Handmade Cocktails","Catering"]},"Cleanup":{"values":["Water and Soap","Specialized Materials","Special Equiment","Hired Help"]},"Food":{"values":["Chips and Nuts","Finger-Food","Handmade Food","Catering"]},"Location":{"values":["Party Tent","Your Dorm","Party Room","Ballroom"]}}},"name":"party1","issueUtilities":{"Invitations":{"DiscreteValueSetUtilities":{"valueUtilities":{"Plain":0.24,"Custom, Printed":0.48,"Photo":0.74,"Custom, Handmade":1}}},"Music":{"DiscreteValueSetUtilities":{"valueUtilities":{"DJ":0.99,"Band":0.35,"MP3":0.65}}},"Drinks":{"DiscreteValueSetUtilities":{"valueUtilities":{"Handmade Cocktails":0.672,"Non-Alcoholic":0.263,"Beer Only":0.98,"Catering":0.334}}},"Cleanup":{"DiscreteValueSetUtilities":{"valueUtilities":{"Special Equiment":0.32,"Water and Soap":0.65,"Specialized Materials":0.96,"Hired Help":0.31}}},"Food":{"DiscreteValueSetUtilities":{"valueUtilities":{"Finger-Food":0.52,"Handmade Food":0.51,"Catering":0.25,"Chips and Nuts":0.75}}},"Location":{"DiscreteValueSetUtilities":{"valueUtilities":{"Your Dorm":0.23,"Ballroom":0.77,"Party Room":0.99,"Party Tent":0.52}}}},"issueWeights":{"Invitations":0.05,"Music":0.19,"Drinks":0.28,"Cleanup":0.10,"Food":0.19,"Location":0.19},"reservationBid":null}}'
    partyjson = json.loads(partystr)

#     def testSerialize(self):
#         print(str(self.pyson.toJson(self.jobsjson)))
#         self.assertEqual(self.valjson, self.pyson.toJson(self.val))
        
    def testDeserialize(self):
        print( str(self.pyson.parse(self.jobsjson, Profile)))
        #self.assertEqual(self.val, self.pyson.parse(self.jobsjson, Profile))
        
    def testDeserializeJapanTrip(self):
        serialized = Path("test/resources/japantrip1.json").read_text("utf-8")
        jsonobj=json.loads(serialized)
        profile:Profile = self.pyson.parse(jsonobj, Profile);
        self.assertEquals("japantrip1", profile.getName())
        self.assertEquals("japantrip", profile.getDomain().getName())
        
    def testDeserializeParty1(self):
        print( str(self.pyson.parse(self.partyjson, Profile)))
